==> foundation-1.1.0.tgz: package/lib/esm/SpecimenProvider.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { ThemeProvider } from "@emotion/react";
import { useMemo } from "react";
import navigationContext from "./navigationContext";
var NavigationProvider = navigationContext.Provider;
var createProxy = function (fn) {
    var proxy = new Proxy({}, {
        get: function (_, query) {
            if (typeof query === "symbol")
                throw new Error("Invalid query");
            try {
                return fn(query).toString();
            }
            catch (_a) {
                return query;
            }
        },
    });
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    return proxy;
};
var processTheme = function (theme) {
    return (__assign(__assign({}, theme), { s: createProxy(theme.size), c: createProxy(theme.color) }));
};
var SpecimenProvider = function (_a) {
    var _b;
    var theme = _a.theme, props = __rest(_a, ["theme"]);
    var processedTheme = useMemo(function () { return processTheme(theme); }, [theme]);
    return (_jsx(NavigationProvider, __assign({ value: (_b = props.navigationFn) !== null && _b !== void 0 ? _b : null }, { children: _jsx(ThemeProvider, __assign({ theme: processedTheme }, { children: props.children })) })));
};
export default SpecimenProvider;

==> foundation-2.3.2.tgz: package/lib/esm/SpecimenProvider.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { ThemeProvider } from "@emotion/react";
import { useMemo } from "react";
import CssReset from "./CssReset";
import navigationContext from "./navigationContext";
var NavigationProvider = navigationContext.Provider;
var createProxy = function (fn) {
    var proxy = new Proxy({}, {
        get: function (_, query) {
            if (typeof query === "symbol")
                throw new Error("Invalid query");
            try {
                return fn(query).toString();
            }
            catch (_a) {
                return query;
            }
        },
    });
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    return proxy;
};
var processTheme = function (theme) {
    return (__assign(__assign({}, theme), { s: createProxy(theme.size), c: createProxy(theme.color) }));
};
var SpecimenProvider = function (_a) {
    var _b;
    var theme = _a.theme, _c = _a.cssReset, cssReset = _c === void 0 ? true : _c, props = __rest(_a, ["theme", "cssReset"]);
    var processedTheme = useMemo(function () { return processTheme(theme); }, [theme]);
    return (_jsxs(NavigationProvider, __assign({ value: (_b = props.navigationFn) !== null && _b !== void 0 ? _b : null }, { children: [cssReset && _jsx(CssReset, {}), _jsx(ThemeProvider, __assign({ theme: processedTheme }, { children: props.children }))] })));
};
export default SpecimenProvider;
